| bqs_rank | R Documentation |
Ranks the scores of clustering methods estimated via bootstrap.
bqs_rank(bqsol, rankby = "lq", boot_na_share = 0.25)
bqsol |
an object of class |
rankby |
character string specifying how the scored solutions are
ranked. Possible values are |
boot_na_share |
a numeric value in |
For small B, some ranking criteria may be unstable or unavailable.
In particular, with B=1, "lq" is effectively equivalent to
"mean", while "1se" is not computable and the corresponding
ranks remain NA. For B<5 warns that "lq" and "1se"
may yield imprecise estimates.
An S3 object of class bqs. Output components are those of
bqs. The score-summary components are re-ranked in place.
Any stored best_* components are refreshed and are returned only when
a rank-1 solution exists under the new ranking. See Value in
bqs. The object is modified only in its ranking-related
components.
Coraggio, Luca and Pietro Coretto (2023). Selecting the number of clusters, clustering models, and algorithms. A unifying approach based on the quadratic discriminant score. Journal of Multivariate Analysis, Vol. 196(105181), 1-20. doi: \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1016/j.jmva.2023.105181")}
bqs, bqs_select
# load data
data("banknote")
dat <- banknote[-1]
## set up methods
## see also help('mset_user') and related functions
KM <- mset_kmeans(K = 3)
GMIX <- mset_gmix(K = 3, erc = c(1, 100))
# combine tuned methods
mlist <- mbind(KM, GMIX)
# perform bootstrap
# change B and ncores to a much larger value in real problems
res <- bqs(dat, mlist, B = 3, rankby = "lq", ncores = 1)
res
# now change ranking criterion
res2 <- bqs_rank(res, rankby = "mean")
res2
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.